@@ -11,7 +11,7 @@ data Dept     = D Name Manager [Unit]  deriving (Eq, Show, Typeable, Data)
 data Unit     = PU Employee | DU Dept  deriving (Eq, Show, Typeable, Data)
 data Employee = E Person Salary        deriving (Eq, Show, Typeable, Data)
 data Person   = P Name Address         deriving (Eq, Show, Typeable, Data)
-data Salary   = S Float                deriving (Eq, Show, Typeable, Data)
+data Salary   = S Double               deriving (Eq, Show, Typeable, Data)
 type Manager  = Employee
 type Name     = String
 type Address  = String
